/*
 * MMap+ - 3d image viewer
 * Copyright 2005, 2006 Masahide Miyake
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef __MMAPTHREAD_H__
#define __MMAPTHREAD_H__

#include <gtk/gtk.h>

typedef void (*MmapThreadFunc) (GObject *);

gint mmapthread_get_n_download (void);

void *mmapthread_download_get (const gchar * uri, gint * return_bytes);
void mmapthread_add_download2 (const gchar * uri, MmapThreadFunc func, GObject * obj);
void mmapthread_add_power (MmapThreadFunc func, GObject * obj);

void mmapthread_init (void);


#endif /* __MMAPTHREAD_H__ */
